local multitotable = function(str)
	local numtable = {}
	local nospace = str:gsub(" ", "")
	for i in nospace:gmatch("%d+")
		numtable[#numtable+1] = i
	end
	return numtable
end

local MapStart = function(mapnum)
	if not mapheaderinfo[mapnum].rhythmmap then return end
	if not MusicSync then return end
	
	S_FadeMusic(0, 1)
	
	local reds = multitotable(tostring(mapheaderinfo[mapnum].redblocktags))
	local blues = multitotable(tostring(mapheaderinfo[mapnum].blueblocktags))
	
	MusicSync.redblocks = {}
	MusicSync.blueblocks = {}
	for i,k in ipairs(reds)
		for sec in sectors.tagged(reds[i])
			if sec.valid
				for fof in sec.ffloors()
					if fof.valid and fof.flags & FOF_EXISTS
						MusicSync.redblocks[#MusicSync.redblocks+1] = fof
						fof.flags = $|FOF_BLOCKPLAYER|FOF_BLOCKOTHERS
					end
				end
			end
		end
	end
	for i,k in ipairs(blues)
		for sec in sectors.tagged(blues[i])
			if sec.valid
				for fof in sec.ffloors()
					if fof.valid and fof.flags & FOF_EXISTS
						MusicSync.blueblocks[#MusicSync.blueblocks+1] = fof
						fof.flags = ($&~(FOF_BLOCKPLAYER|FOF_BLOCKOTHERS))|FOF_TRANSLUCENT
						fof.alpha = 128
					end
				end
			end
		end
	end
end

addHook("MapLoad",MapStart)
//addHook("MapChange",MapStart)

local PlayersInside = function(fof)
	if fof.target and fof.target.valid
		for mo in fof.target.thinglist()
			if mo and mo.valid
			and mo.health and (mo.flags & MF_SHOOTABLE)
			and mo.z-24*mo.scale >= fof.bottomheight and mo.z+mo.height-24*mo.scale <= fof.topheight
				P_DamageMobj(mo,nil,nil,9999,DMG_INSTAKILL)
			end
		end
	end
end

addHook("NetVars", function(net) --Dont care if i run it twice, gotta make that shit SYNC!
	MusicSync = net(MusicSync)
end)

addHook("ThinkFrame", do
	if not mapheaderinfo[gamemap].rhythmmap then return end
	if not MusicSync then return end
	
	if MusicSync.switch
		if MusicSync.redblocks and #MusicSync.redblocks
			for k,v in ipairs(MusicSync.redblocks)
				local fof = MusicSync.redblocks[k]
				if fof and fof.valid
					if fof.flags & FOF_SOLID
						fof.flags = ($&~(FOF_BLOCKPLAYER|FOF_BLOCKOTHERS))|FOF_TRANSLUCENT
						fof.alpha = 128
					else
						fof.flags = ($&~FOF_TRANSLUCENT)|FOF_BLOCKPLAYER|FOF_BLOCKOTHERS
						fof.alpha = 256
						PlayersInside(fof)
					end
				end
			end
		end
		if MusicSync.blueblocks and #MusicSync.blueblocks
			for k,v in ipairs(MusicSync.blueblocks)
				local fof = MusicSync.blueblocks[k]
				if fof and fof.valid
					if fof.flags & FOF_SOLID
						fof.flags = ($&~(FOF_BLOCKPLAYER|FOF_BLOCKOTHERS))|FOF_TRANSLUCENT
						fof.alpha = 128
					else
						fof.flags = ($&~FOF_TRANSLUCENT)|FOF_BLOCKPLAYER|FOF_BLOCKOTHERS
						fof.alpha = 256
						PlayersInside(fof)
					end
				end
			end
		end
		
		if MusicSync.switchobjects
			for k,v in ipairs(MusicSync.switchobjects)
				local mo = MusicSync.switchobjects[k]
				if mo and mo.valid
					if MusicSync.switch
						if (mo.flags & MF_NOCLIPTHING)
							mo.flags = $&~MF_NOCLIPTHING
							mo.rhythmoff = false
						else
							mo.flags = $|MF_NOCLIPTHING
							mo.rhythmoff = true
						end
					end
				end
			end
		end
	end
end)